@@ -34,7 +34,6 @@ Context managers for use with the ``with`` statement.
 """
 
 from contextlib import contextmanager, nested
-import sys
 import socket
 import select
 
@@ -52,9 +51,9 @@ def _set_output(groups, which):
     """
     Refactored subroutine used by ``hide`` and ``show``.
     """
+    previous = {}
     try:
         # Preserve original values, pull in new given value to use
-        previous = {}
         for group in output.expand_aliases(groups):
             previous[group] = output[group]
             output[group] = which
@@ -540,9 +539,9 @@ def remote_tunnel(remote_port, local_port=None, local_host="localhost",
 
         try:
             sock.connect((local_host, local_port))
-        except Exception, e:
+        except Exception:
             print "[%s] rtunnel: cannot connect to %s:%d (from local)" % (env.host_string, local_host, local_port)
-            chan.close()
+            channel.close()
             return
 
         print "[%s] rtunnel: opened reverse tunnel: %r -> %r -> %r"\
@@ -566,7 +565,6 @@ def remote_tunnel(remote_port, local_port=None, local_host="localhost",
         transport.cancel_port_forward(remote_bind_address, remote_port)
 
 
-
 quiet = lambda: settings(hide('everything'), warn_only=True)
 quiet.__doc__ = """
     Alias to ``settings(hide('everything'), warn_only=True)``.
